==> common-1.3.0.39-sources.jar: cn/gtmap/gtc/workflow/enums/manage/ProcQuerykey.java <==
package cn.gtmap.gtc.workflow.enums.manage;

import java.util.HashMap;
import java.util.Map;

public enum ProcQuerykey {

    /**
     * 受理节点归属部门ID
     */
    START_USER_DEP_ID("startUserDepId","受理节点归属部门ID"),



    /**
     * 任务受理人， 用户username, 查询待办已办时，必传
     */
    TASK_ASSIGIN("taskAssigin","任务受理人（用于特殊查询，用于普通查询报错）"),


    /**
     * 任务角色， 用户username, 查询待办已办时，必传
     */
    TASK_ROlE_ID("taskAssRoleId","任务角色Id"),


    /**
     * 流程实例ID
     */
    PROCINSID("procInsId","流程实例ID"),
    /**
     *流程实例名称
     */
    PROCESSINSTANCENAME("processInstanceName","流程实例名称"),
    /**
     *启动流程的开始节点
     */
    STARTACTIVITYID("startActivityId","动流程的开始节点"),
    /**
     *流程启动人相当于 人员username
     */
    STARTUSERID("startUserId","流程启动人相当于"),
    /**
     *流程开始时间
     */
    STARTTIME("startTime","流程开始时间"),
    /**
     *流程结束时间
     */
    ENDTIME("endTime","流程结束时间"),
    /**
     *流程删除原因
     */
    DELETEREASON("deleteReason","流程删除原因"),
    /**
     *流程定义id
     */
    PROCDEFID("procDefId","流程定义id"),
    /**
     *流程定义唯一标识符
     */
    PROCESS_KEY("processKey","流程定义唯一标识符"),
    /**
     *流程到期期限类型
     */
    PROCDUETYPE("procDueType","流程到期期限类型"),
    /**
     *流程到期期限
     */
    PROCDUELIMIT("procDueLimit","流程到期期限"),
    /**
     *流程到期时间
     */
    PROCDUETIME("procDueTime","流程到期时间"),
    /**
     *流程启动人员中文名称
     */
    STARTUSERNAME("startUserName","流程启动人员中文名称"),
    /**
     *流程超期任务数
     */
    PROCTIMEOUTCOUNT("procTimeoutCount","流程超期任务数"),
    /**
     *流程超期状态
     */
    PROCTIMEOUTSTATUS("procTimeoutStatus","流程超期状态"),
    /**
     *流程状态
     */
    PROCSTATUS("procStatus","流程状态"),
    /**
     *流程类别
     */
    CATEGORY("category","流程类别"),

    /**
     *项目ID的
     */
    PROJECTID ("projectId","项目ID"),

    /**
     *项目的名称
     */
    PROJECTNAME  ("projectName","项目的名称");


    private final String value;

    private final String remark;

    public String getValue() {
        return value;
    }

    ProcQuerykey(String value, String remark) {
        this.value = value;
        this.remark = remark;
    }


}

==> common-1.3.0.67-sources.jar: cn/gtmap/gtc/workflow/enums/manage/ProcQuerykey.java <==
package cn.gtmap.gtc.workflow.enums.manage;

import java.util.HashMap;
import java.util.Map;

public enum ProcQuerykey {

    /**
     *流程全部状态（增加加急状态）
     * 不推荐使用
     */
    PROC_All_STATUS("proc_all_status","流程全部状态（特殊查询，QueryJudge.special ）"),

    /**
     * 受理节点归属部门ID
     */
    START_USER_DEP_ID("startUserDepId","受理节点归属部门ID"),


    /**
     * 任务受理人， 用户username, 查询待办已办时，必传
     */
    TASK_ASSIGIN("taskAssigin","任务受理人（用于特殊查询，用于普通查询报错）"),


    /**
     * 任务角色， 用户username, 查询待办已办时，必传
     */
    TASK_ROlE_ID("taskAssRoleId","任务角色Id"),


    /**
     * 流程实例ID
     */
    PROCINSID("procInsId","流程实例ID"),
    /**
     *流程实例名称
     */
    PROCESSINSTANCENAME("processInstanceName","流程实例名称"),
    /**
     *启动流程的开始节点
     */
    STARTACTIVITYID("startActivityId","动流程的开始节点"),
    /**
     *流程启动人相当于 人员code 
     */
    STARTUSERID("startUserId","流程启动人"),
    /**
     *流程开始时间
     */
    STARTTIME("startTime","流程开始时间"),
    /**
     *流程结束时间
     */
    ENDTIME("endTime","流程结束时间"),
    /**
     *流程删除原因
     */
    DELETEREASON("deleteReason","流程删除原因"),
    /**
     *流程定义id
     */
    PROCDEFID("procDefId","流程定义id"),
    /**
     *流程定义唯一标识符
     */
    PROCESS_KEY("processKey","流程定义唯一标识符"),
    /**
     *流程到期期限类型
     */
    PROCDUETYPE("procDueType","流程到期期限类型"),
    /**
     *流程到期期限
     */
    PROCDUELIMIT("procDueLimit","流程到期期限"),
    /**
     *流程到期时间
     */
    PROCDUETIME("procDueTime","流程到期时间"),
    /**
     *流程启动人员中文名称
     */
    STARTUSERNAME("startUserName","流程启动人员中文名称"),
    /**
     *流程超期任务数
     */
    PROCTIMEOUTCOUNT("procTimeoutCount","流程超期任务数"),
    /**
     *流程超期状态
     */
    PROCTIMEOUTSTATUS("procTimeoutStatus","流程超期状态"),
    /**
     *流程状态
     */
    PROCSTATUS("procStatus","流程状态"),
    /**
     *流程类别
     */
    CATEGORY("category","流程类别"),

    /**
     * 优先级
     */
    PRIORITY("priority","优先级"),

    /**
     *项目ID的
     */
    PROJECTID ("projectId","项目ID"),

    /**
     *项目的名称
     */
    PROJECTNAME  ("projectName","项目的名称"),

    /**
     * 加急原因
     */
    PROC_URGENT_REASON("procUrgentReason", "加急原因");


    private final String value;

    private final String remark;

    public String getValue() {
        return value;
    }

    ProcQuerykey(String value, String remark) {
        this.value = value;
        this.remark = remark;
    }


}
